@@ -10,8 +10,13 @@
 #' environment is needed.
 #'
 #' @param path Path to a package, or within a package.
-#' @param dest_path path in which to produce package.  If `NULL`, defaults to
-#'   the parent directory of the package.
+#' @param dest_path path in which to produce package. If it is an existing
+#'   directory, then the output file is placed in `dest_path` and named
+#'   according to the current R conversions (e.g. `.zip` for Windows binary
+#'   packages, `.tgz` for macOS binary packages, etc).
+#'   If it is an existing file, then it will be overwritten.
+#'   If `dest_path` does not exist, then it is used as a file name.
+#'   If `NULL`, it defaults to the parent directory of the package.
 #' @param binary Produce a binary (`--binary`) or source (
 #'   `--no-manual --no-resave-data`) version of the package.
 #' @param vignettes,manual For source packages: if `FALSE`, don't build PDF
@@ -60,8 +65,14 @@ build <- function(path = ".", dest_path = NULL, binary = FALSE, vignettes = TRUE
   out_file <- dir(options$out_dir)
   file.copy(
     file.path(options$out_dir, out_file), options$dest_path,
-    overwrite = TRUE)
-  file.path(options$dest_path, out_file)
+    overwrite = TRUE
+  )
+
+  if (is_dir(options$dest_path)) {
+    file.path(options$dest_path, out_file)
+  } else {
+    options$dest_path
+  }
 }
 
 build_setup <- function(path, dest_path, binary, vignettes, manual, clean_doc, args,
@@ -124,7 +135,16 @@ build_setup_source <- function(path, dest_path, vignettes, manual, clean_doc,
     args <- c(args, "--no-resave-data")
   }
 
-  if (manual && !has_latex()) {
+  if (!manual) {
+    args <- unique(c(args, "--no-manual"))
+  }
+
+  if (!vignettes) {
+    args <- unique(c(args, "--no-build-vignettes"))
+  }
+
+  no_manual <- "--no-manual" %in% args
+  if (!no_manual && !has_latex()) {
     message("pdflatex not found! Not building PDF manual.")
     manual <- FALSE
   }
@@ -133,13 +153,8 @@ build_setup_source <- function(path, dest_path, vignettes, manual, clean_doc,
     check_build_tools(quiet = TRUE)
   }
 
-  if (!manual) {
-    args <- c(args, "--no-manual")
-  }
-
-  if (!vignettes) {
-    args <- c(args, "--no-build-vignettes")
-  } else if (is.null(clean_doc) || isTRUE(clean_doc)) {
+  build_vignettes <- !("--no-build-vignettes" %in% args)
+  if (build_vignettes && (is.null(clean_doc) || isTRUE(clean_doc))) {
     doc_dir <- file.path(path, "inst", "doc")
     if (dir.exists(doc_dir)) {
       if (is.null(clean_doc) && interactive()) {
